@@ -1,7 +1,7 @@
 """
 MIT License
 
-Copyright (c) 2023-present Qvco, Konn
+Copyright (c) 2023-present qvco
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -907,6 +907,21 @@ class RefreshCounterRequestsResponse:
         return f"RefreshCounterRequestsResponse(data={self.data})"
 
 
+class RegisterDeviceTokenResponse:
+    __slots__ = ("data", "id", "server_device_id", "uuid", "created_at", "updated_at")
+
+    def __init__(self, data):
+        self.data = data
+        self.id = data.get("id")
+        self.server_device_id = data.get("server_device_id")
+        self.uuid = data.get("uuid")
+        self.created_at = data.get("created_at")
+        self.updated_at = data.get("updated_at")
+
+    def __repr__(self):
+        return f"RegisterDeviceTokenResponse(data={self.data})"
+
+
 class ReviewsResponse:
     __slots__ = ("data", "reviews", "pinned_reviews")
 
